@@ -25,13 +25,8 @@ class Utils:
         self._config = config
 
         if self._config.get("verbose"):
-            print("Verbose mode enabled")
             logger.setLevel(logging.DEBUG)
 
-    def test(self):
-        logger.info("INFO")
-        logger.debug("DEBUG")
-
     def upload_part(
         self,
         resource: S3Resource,
@@ -74,14 +69,15 @@ class Utils:
     ):
         if key is None:
             key = file_path.split("/")[-1]
-        
+
         if not exist_ok:
             r_headers, r_params, r_body = self._s3.head_object(
                 resource=resource, resource_id=resource_id, key=key
             )
-            if r_headers["ResponseMetadata"]["HTTPStatusCode"] == 200:
+            logger.debug(f"HEAD {resource} ({resource_id}): {key} - {r_body}")
+            if r_body["exists"]:
                 raise FileExistsError(f"File already exists in S3: {key}")
-        
+
         logger.debug("Uploading %s to %s", file_path, key)
         logger.debug("Creating multipart upload for %s %s", resource, resource_id)
         (
